import React, { Fragment } from 'react';
import { storiesOf } from '@storybook/react';
import { host } from 'storybook-host';

import Card from '../Card';
import CardImage from '../CardImage';
import Button from '../../Button';
import Heading from '../../Heading';

export default storiesOf('Card', module).addDecorator(host({
  title: 'A card is a flexible and extensible content container. It includes options for headers and footers, a wide variety of content, contextual background colors, and powerful display options.',
  align: 'center',
  width: 320
})).add('Card', function () {
  return React.createElement(
    Card,
    null,
    React.createElement(
      Card.Body,
      null,
      React.createElement(
        Heading,
        { as: 'h5' },
        'Card title'
      ),
      React.createElement(
        'p',
        null,
        'With supporting text below as a natural lead-in to additional content.'
      ),
      React.createElement(
        Button.Link,
        { href: '#', color: 'primary' },
        'Button'
      )
    )
  );
}).add('With Image', function () {
  return React.createElement(
    Card,
    null,
    React.createElement(CardImage, { src: 'http://placehold.it/318x180', alt: 'card image' }),
    React.createElement(
      Card.Body,
      null,
      React.createElement(
        Heading,
        { as: 'h4' },
        'Card title'
      ),
      React.createElement(
        'p',
        null,
        'Some quick example text to build on the card title and make up the bulk of the card\'s content.'
      ),
      React.createElement(
        Button.Link,
        { href: '#', color: 'primary' },
        'Go somewhere'
      )
    )
  );
}).add('Card with Header and Footer', function () {
  return React.createElement(
    Card,
    null,
    React.createElement(
      Card.Header,
      null,
      'Featured'
    ),
    React.createElement(
      Card.Body,
      null,
      React.createElement(
        Heading,
        { as: 'h4' },
        'Card title'
      ),
      React.createElement(
        'p',
        null,
        'Some quick example text to build on the card title and make up the bulk of the card\'s content.'
      ),
      React.createElement(
        Button.Link,
        { href: '#', color: 'primary' },
        'Go somewhere'
      )
    ),
    React.createElement(
      Card.Footer,
      null,
      '2 days ago'
    )
  );
});