
// $FlowIssue
import darken from 'polished/lib/color/darken';
// $FlowIssue
import lighten from 'polished/lib/color/lighten';
// $FlowIssue
import stripUnit from 'polished/lib/helpers/stripUnit';

import { sassRgba } from './sassRgba';

// General variable structure

// Colors
//
// Grayscale and brand colors for use across Bootstrap.

// Start with assigning color names to specific hex values.

export var white = '#fff';
export var gray100 = '#f8f9fa';
export var gray200 = '#e9ecef';
export var gray300 = '#dee2e6';
export var gray400 = '#ced4da';
export var gray500 = '#adb5bd';
export var gray600 = '#868e96';
export var gray700 = '#495057';
export var gray800 = '#343a40';
export var gray900 = '#212529';
export var black = '#000';

export var blue = '#007bff';
export var indigo = '#6610f2';
export var purple = '#6f42c1';
export var pink = '#e83e8c';
export var red = '#dc3545';
export var orange = '#fd7e14';
export var yellow = '#ffc107';
export var green = '#28a745';
export var teal = '#20c997';
export var cyan = '#17a2b8';

export var colors = {
  blue: blue,
  indigo: indigo,
  purple: purple,
  pink: pink,
  red: red,
  orange: orange,
  yellow: yellow,
  green: green,
  teal: teal,
  cyan: cyan,
  white: white,
  gray: gray600,
  grayDark: gray800
};

export var themeColors = {
  primary: blue,
  secondary: gray600,
  success: green,
  info: cyan,
  warning: yellow,
  danger: red,
  light: gray100,
  dark: gray800
};

// Options
//
// Quickly modify global styling by enabling or disabling optional features.

export var enableRounded = true;
export var enableShadows = false;
export var enableGradients = false;
export var enableTransitions = true;
export var enableHoverMediaQuery = false;
export var enableGridClasses = true;
export var enablePrintStyles = true;

// Spacing
//
// Control the default styling of most Bootstrap elements by modifying these
// variables. Mostly focused on spacing.
// You can add more entries to the $spacers map, should you need more variation.

export var spacer = 1;
export var spacers = {
  s0: 0,
  s1: spacer * 0.25 + 'rem',
  s2: spacer * 0.5 + 'rem',
  s3: spacer,
  s4: spacer * 1.5 + 'rem',
  s5: spacer * 3 + 'rem'
};

export var borderWidth = '1px';

// This variable affects the `.h-*` and `.w-*` classes.
// export const sizes = {
//   s25: '25%',
//   s50: '50%',
//   s75: '75%',
//   s100: '100%'
// };

// Body
//
// Settings for the `<body>` element.

export var bodyBg = white;
export var bodyColor = gray900;

// Links
//
// Style anchor elements.

export var linkColor = themeColors.primary;
export var linkDecoration = 'none';
export var linkHoverColor = darken(0.15, linkColor);
export var linkHoverDecoration = 'underline';

// Components
//
// Define common padding and border radius sizes and more.

export var lineHeightLg = 4 / 3;
export var lineHeightSm = 1.5;

export var borderRadius = '0.25rem';
export var borderRadiusLg = '0.3rem';
export var borderRadiusSm = '0.2rem';

export var componentActiveColor = white;
export var componentActiveBg = themeColors.primary;

export var caretWidth = '0.3em';

export var transitionBase = 'all .2s ease-in-out';
export var transitionFade = 'opacity 0.15s linear';
export var transitionCollapse = 'height 0.35s ease';

// Fonts
//
// Font, lineHeight, and color for body text, headings, and more.

export var fontFamilySansSerif = '-apple-system, system-ui, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif';
export var fontFamilySerif = 'Georgia, "Times New Roman", Times, serif';
export var fontFamilyMonnospace = 'Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace';
export var fontFamilyBase = fontFamilySansSerif;

export var fontSizeBase = '1rem';
export var fontSizeLg = '1.25rem';
export var fontSizeSm = '0.875rem';
export var fontSizeXs = '0.75rem';

export var fontWeightNormal = 'normal';
export var fontWeightBold = 'bold';

export var fontWeightBase = fontWeightNormal;
export var lineHeightBase = 1.5;

export var fontSizeH1 = '2.5rem';
export var fontSizeH2 = '2rem';
export var fontSizeH3 = '1.75rem';
export var fontSizeH4 = '1.5rem';
export var fontSizeH5 = '1.25rem';
export var fontSizeH6 = '1rem';

export var headingsMarginBottom = spacer / 2 + 'rem';
export var headingsFontFamily = 'inherit';
export var headingsFontWeight = 500;
export var btnBoxShadow = 'inset 0 1px 0 rgba(' + white + ',.15), 0 1px 1px ' + sassRgba(black, 0.075);
export var headingsLineHeight = 1.1;
export var headingsColor = 'inherit';

export var zindexDropdown = 1000;
export var zindexSticky = 1020;
export var zindexFixed = 1030;
export var zindexModalBackdrop = 1040;
export var zindexModal = 1050;
export var zindexPopover = 1060;
export var zindexTooltip = 1070;

// Navs

export var navLinkPaddingY = '.5rem';
export var navLinkPaddingX = '1rem';
export var navLinkDisabledColor = gray600;

export var navTabsBorderColor = '#ddd';
export var navTabsBorderWidth = borderWidth;
export var navTabsBorderRadius = borderRadius;
export var navTabsLinkHoverBorderColor = gray200;
export var navTabsLinkActiveColor = gray700;
export var navTabsLinkActiveBg = bodyBg;
export var navTabsLinkActiveBorderColor = '#ddd';

export var navPillsBorderRadius = borderRadius;
export var navPillsLinkActiveColor = componentActiveColor;
export var navPillsLinkActiveBg = componentActiveBg;

// Navbar

export var navbarPaddingY = spacer / 2 + 'rem';
export var navbarPaddingX = spacer;

export var navbarBrandFontSize = fontSizeLg;
// Compute the navbarBrand paddingY so the navbarBrand will have the same height as navbar-text and navLink
export var navLinkHeight = stripUnit(navbarBrandFontSize) * lineHeightBase + 'rem';

export var navbarBrandHeight = stripUnit(fontSizeBase) * lineHeightBase + stripUnit(navLinkPaddingY) * 2 + 'rem';

export var navbarBrandPaddingY = (stripUnit(navbarBrandHeight) - stripUnit(navLinkHeight)) / 2 + 'rem';

export var navbarTogglerPaddingY = '.25rem';
export var navbarTogglerPaddingX = '.75rem';
export var navbarTogglerFontSize = fontSizeLg;
export var navbarTogglerBorderRadius = borderRadius;

export var navbarDarkColor = sassRgba(white, 0.5);
export var navbarDarkHoverColor = sassRgba(white, 0.75);
export var navbarDarkActiveColor = sassRgba(white, 1);
export var navbarDarkDisabledColor = sassRgba(white, 0.25);
export var navbarDarkTogglerIconBg = 'url("data:image/svg+xml;charset=utf8,%3Csvg viewBox=\'0 0 30 30\' xmlns=\'http://www.w3.org/2000/svg\'%3E%3Cpath stroke=\'' + navbarDarkColor + '\' strokeWidth=\'2\' strokeLinecap=\'round\' stroke-miterlimit=\'10\' d=\'M4 7h22M4 15h22M4 23h22\'/%3E%3C/svg%3E")';
export var navbarDarkTogglerBorderColor = sassRgba(white, 0.1);

export var navbarLightColor = sassRgba(black, 0.5);
export var navbarLightHoverColor = sassRgba(black, 0.7);
export var navbarLightActiveColor = sassRgba(black, 0.9);
export var navbarLightDisabledColor = sassRgba(black, 0.3);
export var navbarLightTogglerIconBg = 'url("data:image/svg+xml;charset=utf8,%3Csvg viewBox=\'0 0 30 30\' xmlns=\'http://www.w3.org/2000/svg\'%3E%3Cpath stroke=\'' + navbarLightColor + '\' strokeWidth=\'2\' strokeLinecap=\'round\' stroke-miterlimit=\'10\' d=\'M4 7h22M4 15h22M4 23h22\'/%3E%3C/svg%3E")';
export var navbarLightTogglerBorderColor = sassRgba(black, 0.1);

// Pagination

export var paginationPaddingY = '.5rem';
export var paginationPaddingX = '.75rem';
export var paginationPaddingYsm = '.25rem';
export var paginationPaddingXsm = '.5rem';
export var paginationPaddingYlg = '.75rem';
export var paginationPaddingXlg = '1.5rem';
export var paginationLineHeight = '1.25';

export var paginationColor = linkColor;
export var paginationBg = white;
export var paginationBorderWidth = borderWidth;
export var paginationBorderColor = '#ddd';

export var paginationHoverColor = linkHoverColor;
export var paginationHoverBg = gray200;
export var paginationHoverBorderColor = '#ddd';

export var paginationActiveColor = white;
export var paginationActiveBg = themeColors.primary;
export var paginationActiveBorderColor = themeColors.primary;

export var paginationDisabledColor = gray600;
export var paginationDisabledBg = white;
export var paginationDisabledBorderColor = '#ddd';

// Form states and alerts
//
// Define colors for form feedback states and, by default, alerts.

export var stateSuccessText = '#3c763d';
export var stateSuccessBg = '#dff0d8';
export var stateSuccessBorderColor = darken(0.05, stateSuccessBg);

export var stateInfoText = '#31708f';
export var stateInfoBg = '#d9edf7';
export var stateInfoBorderColor = darken(0.07, stateInfoBg);

export var stateWarningText = '#8a6d3b';
export var stateWarningBg = '#fcf8e3';
export var markBg = stateWarningBg;
export var stateWarningBorderColor = darken(0.05, stateWarningBg);

export var stateDangerText = '#a94442';
export var stateDangerBg = '#f2dede';
export var stateDangerBorderColor = darken(0.05, stateDangerBg);

// Badges

export var badgeDefaultBg = gray600;
export var badgePrimaryBg = themeColors.primary;
export var badgeSuccessBg = themeColors.success;
export var badgeInfoBg = themeColors.info;
export var badgeWarningBg = themeColors.warning;
export var badgeDangerBg = themeColors.danger;

export var badgeColor = white;
export var badgeLinkHoverColor = white;
export var badgeFontSize = '75%';
export var badgeFontWeight = fontWeightBold;
export var badgePaddingY = '.25em';
export var badgePaddingX = '.4em';

export var badgePillPaddingX = '.6em';
// Use a higher than normal value to ensure completely rounded edges when
// customizing padding or fontSize on labels.
export var badgePillBorderRadius = '10rem';

// Buttons
//
// For each of Bootstrap's buttons, define text, background and border color.

export var inputBtnPaddingY = '.5rem';
export var inputBtnPaddingX = '1rem';
export var inputBtnLineHeight = 1.25;

export var inputBtnPaddingYsm = '.25rem';
export var inputBtnPaddingXsm = '.5rem';
export var inputBtnLineHeightSm = 1.5;

export var inputBtnPaddingYlg = '.5rem';
export var inputBtnPaddingXlg = '1rem';
export var inputBtnLineHeightLg = 1.5;

export var btnFontWeight = fontWeightNormal;
// export const btnBoxShadow = `inset 0 1px 0 ${sassRgba(
//   white,
//   0.15
// )}, 0 1px 1px ${sassRgba(black, 0.075)}`;
export var btnFocusBoxShadow = '0 0 0 2px ' + sassRgba(themeColors.primary, 0.25);
export var btnActiveBoxShadow = 'inset 0 3px 5px rgba($black,.125)';

export var btnPrimaryColor = white;
export var btnPrimaryBg = themeColors.primary;
export var btnPrimaryBorderColor = btnPrimaryBg;

export var btnSecondaryColor = gray900;
export var btnSecondaryBg = white;
export var btnSecondaryBorderColor = '#ccc';

export var btnInfoColor = white;
export var btnInfoBg = themeColors.info;
export var btnInfoBorderColor = btnInfoBg;

export var btnSuccessColor = white;
export var btnSuccessBg = themeColors.success;
export var btnSuccessBorderColor = btnSuccessBg;

export var btnWarningColor = white;
export var btnWarningBg = themeColors.warning;
export var btnWarningBorderColor = btnWarningBg;

export var btnDangerColor = white;
export var btnDangerBg = themeColors.danger;
export var btnDangerBorderColor = btnDangerBg;

export var btnLinkDisabledColor = gray600;

export var btnBlockSpacingY = '.5rem';

// Allows for customizing button radius independently from global border radius
export var btnBorderRadius = borderRadius;
export var btnBorderRadiusLg = borderRadiusLg;
export var btnBorderRadiusSm = borderRadiusSm;

export var btnTransition = 'all .2s ease-in-out';

// Forms

export var inputBg = white;
export var inputBgDisabled = gray200;

export var inputColor = gray700;
export var inputBorderColor = sassRgba(black, 0.15);
export var inputBtnBorderWidth = borderWidth; // For form controls ans
export var inputBoxShadow = 'inset 0 1px 1px ' + sassRgba(black, 0.075);

export var inputBorderRadius = borderRadius;
export var inputBorderRadiusLg = borderRadiusLg;
export var inputBorderRadiusSm = borderRadiusSm;
export var inputBgFocus = inputBg;
export var inputBorderColorFocus = lighten(0.25, themeColors.primary);
export var inputBoxShadowFocus = inputBoxShadow + ', ' + sassRgba(inputBorderColorFocus, 0.6);
export var inputColorFocus = inputColor;
export var inputColorPlaceholder = gray600;

export var inputHeight = stripUnit(fontSizeBase) * inputBtnLineHeight + stripUnit(inputBtnPaddingY) * 2 + 'rem';

export var inputHeightLg = stripUnit(fontSizeLg) * inputBtnLineHeightLg + stripUnit(inputBtnPaddingYlg) * 2 + 'rem';

export var inputHeightSm = stripUnit(fontSizeSm) * inputBtnLineHeightSm + stripUnit(inputBtnPaddingYsm) * 2 + 'rem';

export var inputTransition = 'borderColor ease-in-out .15s, box-shadow ease-in-out .15s';

// Dropdowns
//
// Dropdown menu container and contents.

export var dropdownMinWidth = '10rem';
export var dropdownPaddingY = '.5rem';
export var dropdownMarginTop = '.125rem';
export var dropdownBg = white;
export var dropdownBorderColor = sassRgba(black, 0.15);
export var dropdownBorderWidth = borderWidth;
export var dropdownDividerBg = gray200;
export var dropdownBoxShadow = '0 .5rem 1rem ' + sassRgba(black, 0.175);

export var dropdownLinkColor = gray900;
export var dropdownLinkHoverColor = darken(0.05, gray900);
export var dropdownLinkHoverBg = gray100;

export var dropdownLinkActiveColor = componentActiveColor;
export var dropdownLinkActiveBg = componentActiveBg;

export var dropdownLinkDisabledColor = gray600;

export var dropdownItemPaddingY = '.25rem';
export var dropdownItemPaddingX = '1.5rem';

export var dropdownHeaderColor = gray600;

// Alerts
//
// Define alert colors, border radius, and padding.

export var alertPaddingY = '.75rem';
export var alertPaddingX = '1.25rem';
export var alertMarginBottom = '1rem';
export var alertBorderRadius = borderRadius;
export var alertLinkFontWeight = fontWeightBold;
export var alertBorderWidth = borderWidth;

export var alertSuccessBg = stateSuccessBg;
export var alertSuccessText = stateSuccessText;
export var alertSuccessBorderColor = stateSuccessBorderColor;

export var alertInfoBg = stateInfoBg;
export var alertInfoText = stateInfoText;
export var alertInfoBorderColor = stateInfoBorderColor;

export var alertWarningBg = stateWarningBg;
export var alertWarningText = stateWarningText;
export var alertWarningBorderColor = stateWarningBorderColor;

export var alertDangerBg = stateDangerBg;
export var alertDangerText = stateDangerText;
export var alertDangerBorderColor = stateDangerBorderColor;

// Progress bars

export var progressHeight = '1rem';
export var progressFontSize = '.75rem';
export var progressBg = gray200;
export var progressBorderRadius = borderRadius;
export var progressBoxShadow = 'inset 0 .1rem .1rem ' + sassRgba(black, 0.1);
export var progressBarColor = white;
export var progressBarBg = themeColors.primary;
export var progressBarAnimationTiming = '1s linear infinite';
export var progressBarTransition = 'width .6s ease';

// List group

export var listGroupBg = white;
export var listGroupBorderColor = sassRgba(black, 0.125);
export var listGroupBorderWidth = borderWidth;
export var listGroupBorderRadius = borderRadius;

export var listGroupItemPaddingY = '.75rem';
export var listGroupItemPaddingX = '1.25rem';

export var listGroupHoverBg = gray100;
export var listGroupActiveColor = componentActiveColor;
export var listGroupActiveBg = componentActiveBg;
export var listGroupActiveBordeColor = listGroupActiveBg;

export var listGroupDisabledColor = gray600;
export var listGroupDisableddBg = listGroupBg;

export var listGroupActionColor = gray700;
export var listGroupActionHoverColor = listGroupActionColor;

export var listGroupActionActiveColor = bodyColor;
export var listGroupActionActiveBg = gray200;

// Grid columns
//
// Set the number of columns and specify the width of the gutters.

export var gridColumns = 12;
export var gridGutterWidthBase = '30px';
export var gridGutterWidths = {
  xs: gridGutterWidthBase,
  sm: gridGutterWidthBase,
  md: gridGutterWidthBase,
  lg: gridGutterWidthBase,
  xl: gridGutterWidthBase
};

// Breadcrumbs

export var breadcrumbPaddingY = '.75rem';
export var breadcrumbPaddingX = '1rem';
export var breadcrumbItemPadding = '.5rem';
export var breadcrumbBg = gray200;
export var breadcrumbDividerColor = gray600;
export var breadcrumbActiveColor = gray600;
export var breadcrumbDivider = '"/"';

// Jumbotron

export var jumbotronPadding = '2rem';
export var jumbotronBg = gray200;

// Cards

export var cardSpacerY = '.75rem';
export var cardSpacerX = '1.25rem';
export var cardBorderWidth = '1px';
export var cardBorderRadius = borderRadius;
export var cardBorderColor = sassRgba(black, 0.125);
export var cardInnerBorderRadius = 'calc(' + stripUnit(cardBorderRadius) + 'px - ' + stripUnit(cardBorderWidth) + ')}px)';
export var cardCapBg = sassRgba(black, 0.03);
export var cardBg = white;

export var cardInverseLinkHoverColor = white;

export var cardImgOverlayPadding = '1.25rem';

export var cardDeckMargin = stripUnit(gridGutterWidthBase) / 2 + 'px';

export var cardColumnsCount = 3;
export var cardColumnsGap = '1.25rem';
export var cardColumnsMargin = cardSpacerY;